@@ -2,7 +2,7 @@ package Plack::Middleware::Session;
 use strict;
 use warnings;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.02';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use Plack::Session;
@@ -55,7 +55,9 @@ sub call {
     $self->response_cb($res, sub {
         my $res = Plack::Response->new(@{$_[0]});
         $env->{'plack.session'}->finalize( $res );
-        @{$_[0]} = @{$res->finalize};
+        $res = $res->finalize;
+        $_[0]->[0] = $res->[0];
+        $_[0]->[1] = $res->[1];
     });
 }
 
